@@ -908,6 +908,7 @@ MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::Audio)
 MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::Emote)
 MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::File)
 MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::Image)
+MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::Location)
 MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::Notice)
 MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::Text)
 MTXCLIENT_SEND_ROOM_MESSAGE_FWD(mtx::events::msg::Video)
@@ -974,6 +975,7 @@ MTXCLIENT_SEND_TO_DEVICE_FWD(mtx::events::msg::SecretRequest)
 MTXCLIENT_ACCOUNT_DATA_FWD(mtx::events::msc2545::ImagePack)
 MTXCLIENT_ACCOUNT_DATA_FWD(mtx::events::msc2545::ImagePackRooms)
 MTXCLIENT_ACCOUNT_DATA_FWD(mtx::events::account_data::nheko_extensions::HiddenEvents)
+MTXCLIENT_ACCOUNT_DATA_FWD(mtx::events::account_data::nheko_extensions::InvitePermissions)
 MTXCLIENT_ACCOUNT_DATA_FWD(mtx::events::account_data::nheko_extensions::EventExpiry)
 MTXCLIENT_ACCOUNT_DATA_FWD(mtx::events::account_data::Tags)
 MTXCLIENT_ACCOUNT_DATA_FWD(mtx::events::account_data::Direct)
