@@ -23,6 +23,7 @@ from_json(const json &obj, Notice &content)
         content.formatted_body = obj.at("formatted_body").get<std::string>();
 
     content.relations = common::parse_relations(obj);
+    content.mentions  = common::parse_mentions(obj);
 }
 
 void
@@ -36,6 +37,7 @@ to_json(json &obj, const Notice &content)
         obj["formatted_body"] = content.formatted_body;
     }
 
+    common::add_mentions(obj, content.mentions);
     common::apply_relations(obj, content.relations);
 }
 
