@@ -28,6 +28,7 @@ from_json(const json &obj, Video &content)
         content.file = obj.at("file").get<crypto::EncryptedFile>();
 
     content.relations = common::parse_relations(obj);
+    content.mentions  = common::parse_mentions(obj);
 }
 
 void
@@ -42,6 +43,7 @@ to_json(json &obj, const Video &content)
     else
         obj["url"] = content.url;
 
+    common::add_mentions(obj, content.mentions);
     common::apply_relations(obj, content.relations);
 }
 
