@@ -1,7 +1,7 @@
-#include <string>
-
 #include "mtx/events/topic.hpp"
 
+#include <nlohmann/json.hpp>
+
 using json = nlohmann::json;
 
 namespace mtx {
@@ -11,14 +11,14 @@ namespace state {
 void
 from_json(const json &obj, Topic &event)
 {
-        if (!obj.at("topic").is_null())
-                event.topic = obj.at("topic").get<std::string>();
+    if (obj.find("topic") != obj.end() && !obj.at("topic").is_null())
+        event.topic = obj.at("topic").get<std::string>();
 }
 
 void
 to_json(json &obj, const Topic &event)
 {
-        obj["topic"] = event.topic;
+    obj["topic"] = event.topic;
 }
 
 } // namespace state
