@@ -140,6 +140,11 @@ parse_room_account_data_events(
                 container.emplace_back(events::AccountDataEvent<nheko_extensions::EventExpiry>(e));
                 break;
             }
+            case events::EventType::NhekoInvitePermissions: {
+                container.emplace_back(
+                  events::AccountDataEvent<nheko_extensions::InvitePermissions>(e));
+                break;
+            }
             case events::EventType::ImagePackRooms: {
                 container.emplace_back(
                   events::AccountDataEvent<events::msc2545::ImagePackRooms>(e));
@@ -424,8 +429,7 @@ parse_timeline_events(const json &events,
                     break;
                 }
                 case MsgType::Location: {
-                    /* events::RoomEvent<events::msg::Location> location = e; */
-                    /* container.emplace_back(location); */
+                    container.emplace_back(events::RoomEvent<events::msg::Location>(e));
                     break;
                 }
                 case MsgType::Notice: {
@@ -528,6 +532,7 @@ parse_timeline_events(const json &events,
             case events::EventType::IgnoredUsers:
             case events::EventType::NhekoHiddenEvents:
             case events::EventType::NhekoEventExpiry:
+            case events::EventType::NhekoInvitePermissions:
             case events::EventType::ImagePackRooms:
             case events::EventType::ImagePackInAccountData:
             case events::EventType::Dummy:
@@ -808,6 +813,7 @@ parse_state_events(const json &events,
             case events::EventType::IgnoredUsers:
             case events::EventType::NhekoHiddenEvents:
             case events::EventType::NhekoEventExpiry:
+            case events::EventType::NhekoInvitePermissions:
             case events::EventType::ImagePackRooms:
             case events::EventType::ImagePackInAccountData:
             case events::EventType::Dummy:
@@ -977,6 +983,7 @@ parse_stripped_events(const json &events,
             case events::EventType::IgnoredUsers:
             case events::EventType::NhekoHiddenEvents:
             case events::EventType::NhekoEventExpiry:
+            case events::EventType::NhekoInvitePermissions:
             case events::EventType::ImagePackInAccountData:
             case events::EventType::ImagePackInRoom:
             case events::EventType::ImagePackRooms:
