@@ -13,11 +13,10 @@ from_json(const nlohmann::json &obj, Members &res)
     if (obj.contains("chunk")) {
         for (const auto &e : obj["chunk"]) {
             try {
-                mtx::events::StateEvent<mtx::events::state::Member> member = e;
-                res.chunk.push_back(member);
+                res.chunk.push_back(e.get<mtx::events::StateEvent<mtx::events::state::Member>>());
             } catch (const std::exception &e) {
-                utils::log::log_warning(
-                  std::string("Failed to parse member event in members chunk: ") + e.what());
+                utils::log::log()->warn("Failed to parse member event in members chunk: {}",
+                                        e.what());
             }
         }
     }
