@@ -1,6 +1,8 @@
 #include "mtx/responses/messages.hpp"
 #include "mtx/responses/common.hpp"
 
+#include <nlohmann/json.hpp>
+
 using json = nlohmann::json;
 
 namespace mtx {
@@ -9,9 +11,10 @@ namespace responses {
 void
 from_json(const json &obj, Messages &messages)
 {
-        messages.start = obj.at("start").get<std::string>();
-        messages.end   = obj.at("end").get<std::string>();
+    messages.start = obj.value("start", "");
+    messages.end   = obj.value("end", "");
 
+    if (obj.contains("chunk"))
         utils::parse_timeline_events(obj.at("chunk"), messages.chunk);
 }
 }
