@@ -59,7 +59,27 @@ TEST(Pushrules, GlobalRuleset)
         ],
         "default": true,
         "rule_id": ".m.rule.suppress_notices"
-      }
+      },
+        {
+          "actions": [
+            "notify",
+            {
+              "set_tweak": "highlight"
+            },
+            {
+              "set_tweak": "sound",
+              "value": "default"
+            }
+          ],
+          "conditions": [
+            {
+              "key": "content.m\\.mentions.user_ids",
+              "kind": "event_property_contains"
+            }
+          ],
+          "default": true,
+          "rule_id": ".m.rule.is_user_mention"
+        }
     ],
     "room": [],
     "sender": [],
@@ -213,7 +233,7 @@ TEST(Pushrules, GlobalRuleset)
     EXPECT_TRUE(std::holds_alternative<ns::actions::set_tweak_highlight>(
       rules.global.content.at(0).actions.at(2)));
 
-    // EXPECT_EQ(rules.global.override_.size(), 2);
+    EXPECT_EQ(rules.global.override_.size(), 3);
     EXPECT_EQ(rules.global.room.size(), 0);
     EXPECT_EQ(rules.global.sender.size(), 0);
     EXPECT_EQ(rules.global.underride.size(), 6);
@@ -413,6 +433,521 @@ TEST(Pushrules, RoomRuleMentions)
     client->close();
 }
 
+TEST(Pushrules, ExplicitMentions)
+{
+    nlohmann::json raw_rule = R"(
+{
+  "global": {
+    "underride": [
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.call.invite"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "sound",
+            "value": "ring"
+          },
+          {
+            "set_tweak": "highlight",
+            "value": false
+          }
+        ],
+        "rule_id": ".m.rule.call",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.message"
+          },
+          {
+            "kind": "room_member_count",
+            "is": "2"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          },
+          {
+            "set_tweak": "highlight",
+            "value": false
+          }
+        ],
+        "rule_id": ".m.rule.room_one_to_one",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.encrypted"
+          },
+          {
+            "kind": "room_member_count",
+            "is": "2"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          },
+          {
+            "set_tweak": "highlight",
+            "value": false
+          }
+        ],
+        "rule_id": ".m.rule.encrypted_room_one_to_one",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.message"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          },
+          {
+            "set_tweak": "highlight",
+            "value": false
+          }
+        ],
+        "rule_id": ".m.rule.message",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.encrypted"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          },
+          {
+            "set_tweak": "highlight",
+            "value": false
+          }
+        ],
+        "rule_id": ".m.rule.encrypted",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "im.vector.modular.widgets"
+          },
+          {
+            "kind": "event_match",
+            "key": "content.type",
+            "pattern": "jitsi"
+          },
+          {
+            "kind": "event_match",
+            "key": "state_key",
+            "pattern": "*"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight",
+            "value": false
+          }
+        ],
+        "rule_id": ".im.vector.jitsi",
+        "default": true,
+        "enabled": true
+      }
+    ],
+    "sender": [],
+    "room": [],
+    "content": [
+      {
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight"
+          },
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          }
+        ],
+        "rule_id": ".m.rule.contains_user_name",
+        "default": true,
+        "pattern": "deepbluev7",
+        "enabled": true
+      }
+    ],
+    "override": [
+      {
+        "conditions": [],
+        "actions": [],
+        "rule_id": ".m.rule.master",
+        "default": true,
+        "enabled": false
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "content.msgtype",
+            "pattern": "m.notice"
+          }
+        ],
+        "actions": [],
+        "rule_id": ".m.rule.suppress_notices",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.member"
+          },
+          {
+            "kind": "event_match",
+            "key": "content.membership",
+            "pattern": "invite"
+          },
+          {
+            "kind": "event_match",
+            "key": "state_key",
+            "pattern": "@deepbluev7:neko.dev"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight",
+            "value": false
+          },
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          }
+        ],
+        "rule_id": ".m.rule.invite_for_me",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.member"
+          }
+        ],
+        "actions": [],
+        "rule_id": ".m.rule.member_event",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "im.nheko.msc3664.related_event_match",
+            "key": "sender",
+            "rel_type": "m.in_reply_to",
+            "pattern": "@deepbluev7:neko.dev"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight"
+          },
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          }
+        ],
+        "rule_id": ".im.nheko.msc3664.reply",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_property_contains",
+            "key": "content.m\\.mentions.user_ids",
+            "value": "@deepbluev7:neko.dev"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight"
+          },
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          }
+        ],
+        "rule_id": ".m.rule.is_user_mention",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "contains_display_name"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "sound",
+            "value": "default"
+          },
+          {
+            "set_tweak": "highlight"
+          }
+        ],
+        "rule_id": ".m.rule.contains_display_name",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_property_is",
+            "key": "content.m\\.mentions.room",
+            "value": true
+          },
+          {
+            "kind": "sender_notification_permission",
+            "key": "room"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight"
+          }
+        ],
+        "rule_id": ".m.rule.is_room_mention",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "sender_notification_permission",
+            "key": "room"
+          },
+          {
+            "kind": "event_match",
+            "key": "content.body",
+            "pattern": "@room"
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight"
+          }
+        ],
+        "rule_id": ".m.rule.roomnotif",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.tombstone"
+          },
+          {
+            "kind": "event_match",
+            "key": "state_key",
+            "pattern": ""
+          }
+        ],
+        "actions": [
+          "notify",
+          {
+            "set_tweak": "highlight"
+          }
+        ],
+        "rule_id": ".m.rule.tombstone",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.reaction"
+          }
+        ],
+        "actions": [],
+        "rule_id": ".m.rule.reaction",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_match",
+            "key": "type",
+            "pattern": "m.room.server_acl"
+          },
+          {
+            "kind": "event_match",
+            "key": "state_key",
+            "pattern": ""
+          }
+        ],
+        "actions": [],
+        "rule_id": ".m.rule.room.server_acl",
+        "default": true,
+        "enabled": true
+      },
+      {
+        "conditions": [
+          {
+            "kind": "event_property_is",
+            "key": "content.m\\.relates_to.rel_type",
+            "value": "m.replace"
+          }
+        ],
+        "actions": [],
+        "rule_id": ".m.rule.suppress_edits",
+        "default": true,
+        "enabled": true
+      }
+    ]
+  }
+})"_json;
+
+    mtx::pushrules::GlobalRuleset ruleset = raw_rule.get<mtx::pushrules::GlobalRuleset>();
+
+    mtx::pushrules::PushRuleEvaluator evaluator{ruleset.global};
+    mtx::pushrules::PushRuleEvaluator::RoomContext ctx{};
+    ctx.user_display_name = "Nico";
+
+    auto simple_explicit = R"({
+    "content": {
+        "body": "Nico",
+        "format": "org.matrix.custom.html",
+        "formatted_body": "<a href=\"https://matrix.to/#/%40deepbluev7%3Aneko.dev\">Nico</a>",
+        "m.mentions": {
+            "user_ids": [
+                "@deepbluev7:neko.dev"
+            ]
+        },
+        "msgtype": "m.text"
+    },
+    "event_id": "$eRdwtw6KD2SRUJL9RyPUP9kkVcK90NqK3S2DbJXltL0",
+    "origin_server_ts": 1709919179046,
+    "sender": "@test:neko.dev",
+    "type": "m.room.message",
+    "unsigned": {
+        "age": 61
+    }
+})"_json.get<mtx::events::RoomEvent<mtx::events::msg::Text>>();
+
+    auto simple_explicit_actions = evaluator.evaluate({simple_explicit}, ctx, {});
+
+    std::vector<mtx::pushrules::actions::Action> highlight_actions = {
+      mtx::pushrules::actions::notify{},
+      mtx::pushrules::actions::set_tweak_highlight{},
+      mtx::pushrules::actions::set_tweak_sound{},
+    };
+    std::vector<mtx::pushrules::actions::Action> highlight_actions2 = {
+      mtx::pushrules::actions::notify{},
+      mtx::pushrules::actions::set_tweak_sound{},
+      mtx::pushrules::actions::set_tweak_highlight{},
+    };
+    std::vector<mtx::pushrules::actions::Action> no_highlight_actions = {
+      mtx::pushrules::actions::notify{},
+      mtx::pushrules::actions::set_tweak_sound{},
+      mtx::pushrules::actions::set_tweak_highlight{false},
+    };
+
+    EXPECT_EQ(simple_explicit_actions, highlight_actions);
+
+    auto simple_explicit_empty = R"({
+    "content": {
+        "body": "Nico",
+        "format": "org.matrix.custom.html",
+        "formatted_body": "<a href=\"https://matrix.to/#/%40deepbluev7%3Aneko.dev\">Nico</a>",
+        "m.mentions": {
+            "user_ids": [
+            ]
+        },
+        "msgtype": "m.text"
+    },
+    "event_id": "$eRdwtw6KD2SRUJL9RyPUP9kkVcK90NqK3S2DbJXltL0",
+    "origin_server_ts": 1709919179046,
+    "sender": "@test:neko.dev",
+    "type": "m.room.message",
+    "unsigned": {
+        "age": 61
+    }
+})"_json.get<mtx::events::RoomEvent<mtx::events::msg::Text>>();
+
+    auto simple_explicit_empty_actions = evaluator.evaluate({simple_explicit_empty}, ctx, {});
+    EXPECT_EQ(simple_explicit_empty_actions, no_highlight_actions);
+
+    auto simple = R"({
+    "content": {
+        "body": "Nico",
+        "format": "org.matrix.custom.html",
+        "formatted_body": "<a href=\"https://matrix.to/#/%40deepbluev7%3Aneko.dev\">Nico</a>",
+        "msgtype": "m.text"
+    },
+    "event_id": "$eRdwtw6KD2SRUJL9RyPUP9kkVcK90NqK3S2DbJXltL0",
+    "origin_server_ts": 1709919179046,
+    "sender": "@test:neko.dev",
+    "type": "m.room.message",
+    "unsigned": {
+        "age": 61
+    }
+})"_json.get<mtx::events::RoomEvent<mtx::events::msg::Text>>();
+
+    auto simple_actions = evaluator.evaluate({simple}, ctx, {});
+    EXPECT_EQ(simple_actions, highlight_actions2);
+}
 TEST(Pushrules, EventMatches)
 {
     mtx::pushrules::PushRule event_match_rule;
@@ -424,6 +959,7 @@ TEST(Pushrules, EventMatches)
       .kind    = "event_match",
       .key     = "content.body",
       .pattern = "honk",
+      .value   = std::nullopt,
       .is      = "",
     });
 
@@ -513,6 +1049,7 @@ TEST(Pushrules, DisplaynameMatches)
       .kind    = "contains_display_name",
       .key     = "",
       .pattern = "",
+      .value   = std::nullopt,
       .is      = "",
     });
 
@@ -586,6 +1123,7 @@ TEST(Pushrules, PowerLevelMatches)
       .kind    = "sender_notification_permission",
       .key     = "room",
       .pattern = "",
+      .value   = std::nullopt,
       .is      = "",
     });
 
@@ -642,6 +1180,7 @@ TEST(Pushrules, MemberCountMatches)
             .kind    = "room_member_count",
             .key     = "",
             .pattern = "",
+            .value   = std::nullopt,
             .is      = is,
           },
         };
@@ -667,6 +1206,128 @@ TEST(Pushrules, MemberCountMatches)
     testEval("<100", true, false, false);
 }
 
+TEST(Pushrules, EventPropertyIsMatches)
+{
+    mtx::pushrules::PushRule event_match_rule;
+    event_match_rule.actions = {
+      mtx::pushrules::actions::notify{},
+      mtx::pushrules::actions::set_tweak_highlight{},
+    };
+    event_match_rule.conditions.push_back(mtx::pushrules::PushCondition{
+      .kind    = "event_property_is",
+      .key     = "content.body",
+      .pattern = "",
+      .value   = "honk",
+      .is      = "",
+    });
+
+    mtx::events::RoomEvent<mtx::events::msg::Text> textEv{};
+    textEv.content.body = "honk";
+    textEv.room_id      = "!abc:def.ghi";
+    textEv.event_id     = "$abc1234567890:def.ghi";
+    textEv.sender       = "@me:def.ghi";
+
+    auto testEval = [actions = event_match_rule.actions,
+                     &textEv](const mtx::pushrules::PushRuleEvaluator &evaluator) {
+        mtx::pushrules::PushRuleEvaluator::RoomContext ctx{};
+        EXPECT_EQ(evaluator.evaluate({textEv}, ctx, {}), actions);
+
+        auto textEvNo         = textEv;
+        textEvNo.content.body = "hon";
+        EXPECT_TRUE(evaluator.evaluate({textEvNo}, ctx, {}).empty());
+        auto textEvNo2         = textEv;
+        textEvNo2.content.body = "honkb";
+        EXPECT_TRUE(evaluator.evaluate({textEvNo2}, ctx, {}).empty());
+        auto textEvWordBoundaries         = textEv;
+        textEvWordBoundaries.content.body = "@honk:";
+        EXPECT_TRUE(evaluator.evaluate({textEvWordBoundaries}, ctx, {}).empty());
+    };
+
+    mtx::pushrules::Ruleset override_ruleset;
+    override_ruleset.override_.push_back(event_match_rule);
+    mtx::pushrules::PushRuleEvaluator over_evaluator{override_ruleset};
+    testEval(over_evaluator);
+
+    mtx::pushrules::Ruleset underride_ruleset;
+    underride_ruleset.underride.push_back(event_match_rule);
+    mtx::pushrules::PushRuleEvaluator under_evaluator{underride_ruleset};
+    testEval(under_evaluator);
+
+    mtx::pushrules::Ruleset room_ruleset;
+    auto room_rule    = event_match_rule;
+    room_rule.rule_id = "!abc:def.ghi";
+    room_ruleset.room.push_back(room_rule);
+    mtx::pushrules::PushRuleEvaluator room_evaluator{room_ruleset};
+    EXPECT_EQ(room_evaluator.evaluate({textEv}, {}, {}), room_rule.actions);
+
+    mtx::pushrules::Ruleset sender_ruleset;
+    auto sender_rule    = event_match_rule;
+    sender_rule.rule_id = "@me:def.ghi";
+    sender_ruleset.sender.push_back(sender_rule);
+    mtx::pushrules::PushRuleEvaluator sender_evaluator{sender_ruleset};
+    EXPECT_EQ(sender_evaluator.evaluate({textEv}, {}, {}), sender_rule.actions);
+
+    mtx::pushrules::PushRule event_match_5_rule;
+    event_match_rule.actions = {
+      mtx::pushrules::actions::notify{},
+      mtx::pushrules::actions::set_tweak_highlight{},
+    };
+    event_match_rule.conditions.push_back(mtx::pushrules::PushCondition{
+      .kind    = "event_property_is",
+      .key     = "content.info.size",
+      .pattern = "",
+      .value   = 5,
+      .is      = "",
+    });
+    mtx::pushrules::Ruleset match5_ruleset;
+    match5_ruleset.override_.push_back(event_match_rule);
+    mtx::pushrules::PushRuleEvaluator over_evaluator5{match5_ruleset};
+    mtx::events::RoomEvent<mtx::events::msg::Image> imageEv{};
+    imageEv.content.info.size = 5;
+    mtx::pushrules::PushRuleEvaluator::RoomContext ctx{};
+    EXPECT_EQ(over_evaluator5.evaluate({imageEv}, ctx, {}), event_match_5_rule.actions);
+    imageEv.content.info.size = 6;
+    EXPECT_TRUE(over_evaluator5.evaluate({imageEv}, ctx, {}).empty());
+}
+
+TEST(Pushrules, EventPropertyContainsMatches)
+{
+    mtx::pushrules::PushRule event_match_rule;
+    event_match_rule.actions = {
+      mtx::pushrules::actions::notify{},
+      mtx::pushrules::actions::set_tweak_highlight{},
+    };
+    event_match_rule.conditions.push_back(mtx::pushrules::PushCondition{
+      .kind    = "event_property_contains",
+      .key     = "content.via",
+      .pattern = "",
+      .value   = "honk",
+      .is      = "",
+    });
+
+    mtx::events::StateEvent<mtx::events::state::space::Child> childEv{};
+    childEv.content.via = {"honk"};
+    childEv.room_id     = "!abc:def.ghi";
+    childEv.event_id    = "$abc1234567890:def.ghi";
+    childEv.sender      = "@me:def.ghi";
+
+    mtx::pushrules::Ruleset override_ruleset;
+    override_ruleset.override_.push_back(event_match_rule);
+    mtx::pushrules::PushRuleEvaluator evaluator{override_ruleset};
+    mtx::pushrules::PushRuleEvaluator::RoomContext ctx{};
+
+    EXPECT_EQ(evaluator.evaluate({childEv}, ctx, {}), event_match_rule.actions);
+
+    childEv.content.via = {"abc", "honk", ""};
+    EXPECT_EQ(evaluator.evaluate({childEv}, ctx, {}), event_match_rule.actions);
+
+    childEv.content.via = {};
+    EXPECT_TRUE(evaluator.evaluate({childEv}, ctx, {}).empty());
+
+    childEv.content.via = {"not honk"};
+    EXPECT_TRUE(evaluator.evaluate({childEv}, ctx, {}).empty());
+}
+
 TEST(Pushrules, ContentOverRoomRulesMatches)
 {
     json raw_rule = R"(
