@@ -1036,13 +1036,24 @@ TEST(Responses, Messages)
 	  "room_id": "!Xq3620DUiqCaoxq:example.com",
 	  "type": "m.room.name",
 	  "age": 50789
-	 }
+    }, {
+      "origin_server_ts": 1444812198888,
+      "sender": "@bob:example.com",
+      "event_id": "$1444812213350496Cdddd:example.com",
+      "content": {
+        "body": "i like custom things",
+        "msgtype": "im.nheko.test_msgtype"
+      },
+      "room_id": "!Xq3620DUiqCaoxq:example.com",
+      "type": "m.room.message",
+      "age": 69290
+    }
 	]})"_json;
 
     Messages messages = data.get<Messages>();
     EXPECT_EQ(messages.start, "t47429-4392820_219380_26003_2265");
     EXPECT_EQ(messages.end, "t47409-4357353_219380_26003_2265");
-    EXPECT_EQ(messages.chunk.size(), 3);
+    EXPECT_EQ(messages.chunk.size(), 4);
 
     using mtx::events::RoomEvent;
     using mtx::events::StateEvent;
@@ -1067,9 +1078,16 @@ TEST(Responses, Messages)
     EXPECT_EQ(third_event.event_id, "$1444812213350496Ccccc:example.com");
     EXPECT_EQ(third_event.sender, "@bob:example.com");
 
-    // Two of the events are malformed
+    auto fourth_event = std::get<RoomEvent<mtx::events::msg::Unknown>>(messages.chunk[3]);
+    EXPECT_EQ(fourth_event.content.body, "i like custom things");
+    EXPECT_EQ(fourth_event.content.msgtype, "im.nheko.test_msgtype");
+    EXPECT_EQ(fourth_event.type, mtx::events::EventType::RoomMessage);
+    EXPECT_EQ(fourth_event.event_id, "$1444812213350496Cdddd:example.com");
+
+    // Three of the events are malformed
     // 1. Missing "type" key and should be dropped.
     // 2. Content is null and should be parsed as redacted.
+    // 3. msgtype is not a string and should be dropped.
     json malformed_data = R"({
 	"start": "t47429-4392820_219380_26003_2265",
 	"end": "t47409-4357353_219380_26003_2265",
@@ -1091,7 +1109,21 @@ TEST(Responses, Messages)
 	  "room_id": "!Xq3620DUiqCaoxq:example.com",
 	  "type": "m.room.message",
 	  "age": 20123
-	}, {
+    }, {
+      "origin_server_ts": 1510489356530,
+      "sender": "@nheko_test:matrix.org",
+      "event_id": "$15104893562785758wEgEU:matrix.org",
+      "unsigned": {
+        "age": 2225,
+        "transaction_id": "m1510489356267.2"
+      },
+      "content": {
+        "body": "DON'T PANIC",
+        "msgtype": 42
+      },
+      "type": "m.room.message",
+      "room_id": "!lfoDRlNFWlvOnvkBwQ:matrix.org"
+    }, {
 	  "origin_server_ts": 1444812163990,
 	  "sender": "@bob:example.com",
 	  "event_id": "$1444812213350496Ccccc:example.com",
@@ -1689,3 +1721,48 @@ TEST(Response, Users)
     EXPECT_EQ(users.results[0].user_id, "@foo:bar.com");
     EXPECT_EQ(users.limited, false);
 }
+
+TEST(Response, PreviewURL)
+{
+    // Tests with both actual numbers and strings containing them, as both may be returned
+    json fullData = R"({
+          "og:title": "Example",
+          "og:url": "https://example.org",
+          "og:image:type": "image/png",
+          "og:image:width": 12345,
+          "og:image:height": 12345,
+          "og:image:alt": "Alt text",
+          "og:image": "mxc://example.org/abc",
+          "matrix:image:size": 12345,
+          "og:description": "Description",
+          "og:site_name": "example.org"
+        })"_json;
+
+    URLPreview full = fullData.get<URLPreview>();
+    ASSERT_EQ(full.title, "Example");
+    ASSERT_EQ(full.url, "https://example.org");
+    ASSERT_EQ(full.image.type, "image/png");
+    ASSERT_EQ(full.image.width, 12345);
+    ASSERT_EQ(full.image.height, 12345);
+    ASSERT_EQ(full.image.alt, "Alt text");
+    ASSERT_EQ(full.image.url, "mxc://example.org/abc");
+    ASSERT_EQ(full.image.size, 12345);
+    ASSERT_TRUE(full.site_name);
+    ASSERT_TRUE(full.description);
+    ASSERT_EQ(*full.description, "Description");
+    ASSERT_EQ(*full.site_name, "example.org");
+
+    json minData   = R"({
+          "og:title": "Example",
+          "og:url": "https://example.org",
+          "og:image": "mxc://example.org/abc",
+          "matrix:image:size": 12345
+        })"_json;
+    URLPreview min = minData.get<URLPreview>();
+    ASSERT_EQ(min.title, "Example");
+    ASSERT_EQ(min.url, "https://example.org");
+    ASSERT_EQ(min.image.url, "mxc://example.org/abc");
+    ASSERT_EQ(min.image.size, 12345);
+    ASSERT_FALSE(min.site_name);
+    ASSERT_FALSE(min.description);
+}
\ No newline at end of file
